@@ -1,4 +1,3 @@
-import logging
 import wikitextparser
 
 from .wikilinks import (
@@ -7,8 +6,6 @@ from .wikilinks import (
 )
 from ..prototype import WikiTextHtml
 
-log = logging.getLogger(__name__)
-
 WIKILINK_NAMESPACES = {
     "file": file.replace,
     "media": file.replace,
@@ -29,7 +26,7 @@ def replace(instance: WikiTextHtml, wikitext: wikitextparser.WikiText):
             namespace, _, _ = title.rpartition(":")
             if namespace:
                 if namespace not in WIKILINK_NAMESPACES:
-                    log.error(f"Unregistered link namespace: {namespace}")
+                    instance.add_error(f"Namespace '{namespace}' in wikilink is an unknown namespace")
                     continue
 
                 if WIKILINK_NAMESPACES[namespace](instance, wikilink):
